==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
export let GridColumnHideOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnHideOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnHideOptionsDescriptionMetadata.a == null) {
                GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
            }
            if (a.j(GridColumnHideOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnHideOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnHideOptionsDescriptionMetadata.b(a);
            a.aa("GridColumnHideOptions", () => new GridColumnHideOptionsDescription());
            a.z("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
        }
    }
    GridColumnHideOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
export let GridColumnHideOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnHideOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnHideOptionsDescriptionMetadata.a == null) {
                GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnHideOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnHideOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnHideOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnHideOptions", () => new GridColumnHideOptionsDescription());
            a.ab("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
        }
    }
    GridColumnHideOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
})();
